@@ -5,11 +5,13 @@
 
 int main()
 {
-	vector<string> packages,useless;
+	vector<string> packages;
 	vector<owner> explain;
-	read_dpkg(packages, useless, false);
+	dpkg_start();
+	read_dpkg_header(packages);
+	dpkg_end();
 	read_explain("/etc/cruft/explain/", packages, explain);
 	for (unsigned int i=0;i<explain.size();i++) {
-		cout << explain[i].package << ' ' << explain[i].glob << endl;
+		cout << explain[i].package << ' ' << explain[i].path << endl;
 	}
 }
