@@ -5,12 +5,13 @@
 
 int main()
 {
-	vector<string> packages,useless;
+	vector<string> packages;
 	vector<owner> globs;
-	read_dpkg(packages, useless, false);
+	dpkg_start();
+	read_dpkg_header(packages);
+	dpkg_end();
 	read_filters("/etc/cruft/filters/", "/usr/share/cruft/ruleset", packages, globs);
 	for (unsigned int i=0;i<globs.size();i++) {
-		//cout << globs[i].glob << endl;
-		cout << globs[i].package << ' ' << globs[i].glob  << endl;
+		cout << globs[i].package << ' ' << globs[i].path << endl;
 	}
 }
